==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/eu.js <==
OC.L10N.register(
    "files_external",
    {
    "Personal" : "Pertsonala",
    "System" : "Sistema",
    "Grant access" : "Baimendu sarrera",
    "Generate keys" : "Sortu gakoak",
    "All users. Type to select user or group." : "Erabiltzaile guztiak. Idatzi erabiltzaile edo taldea hautatzeko.",
    "(group)" : "(taldea)",
    "Enable encryption" : "Gaitu zifratzea",
    "Enable previews" : "Gaitu aurrebistak",
    "Never" : "inoiz ez",
    "Delete" : "Ezabatu",
    "Saved" : "Gordeta",
    "Saving..." : "Gordetzen...",
    "Save" : "Gorde",
    "Username" : "Erabiltzaile izena",
    "Password" : "Pasahitza",
    "Credentials saved" : "Kredentzialak gordeta",
    "%s" : "%s",
    "Secret key" : "Gako sekretua",
    "None" : "Ezer",
    "OAuth1" : "OAuth1",
    "App key" : "Aplikazio gakoa",
    "App secret" : "App sekretua",
    "OAuth2" : "OAuth2",
    "Client ID" : "Bezero ID",
    "Client secret" : "Bezeroaren Sekretua",
    "OpenStack v2" : "OpenStack v2",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domeinua",
    "API key" : "APIaren gakoa",
    "Username and password" : "Erabiltzaile-izena eta pasahitza",
    "RSA public key" : "RSA gako publikoa",
    "Public key" : "Gako publikoa",
    "RSA private key" : "RSA gako pribatua",
    "Private key" : "Gako pribatua",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "Ostalari izena",
    "Port" : "Portua",
    "Region" : "Eskualdea",
    "Enable SSL" : "Gaitu SSL",
    "Enable Path Style" : "Gaitu Bide Estiloa",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Urruneko azpikarpeta",
    "Secure https://" : "https:// segurua",
    "FTP" : "FTP",
    "Host" : "Ostalaria",
    "Secure ftps://" : "ftps:// segurua",
    "Local" : "Bertakoa",
    "Location" : "Kokapena",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Erroa",
    "Share" : "Partekatu",
    "SMB / CIFS using OC login" : "SMB / CIFS saioa hasteko OC erabiliz",
    "Username as share" : "Erabiltzaile izena elkarbanaketa bezala",
    "OpenStack Object Storage" : "OpenStack Objektu Biltegiratzea",
    "Service name" : "Zerbitzuaren izena",
    "Name" : "Izena",
    "Storage type" : "Biltegiratze mota",
    "Scope" : "Esparrua",
    "Folder name" : "Karpetaren izena",
    "External storage" : "Kanpoko biltegiratzea",
    "Authentication" : "Autentifikazioa",
    "Configuration" : "Konfigurazioa",
    "Available for" : "Hauentzat eskuragarri",
    "Add storage" : "Gehitu biltegiratzea",
    "Advanced settings" : "Ezarpen aurreratuak"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/eu.js <==
OC.L10N.register(
    "files_external",
    {
    "Personal" : "Pertsonala",
    "System" : "Sistema",
    "Grant access" : "Baimendu sarrera",
    "Generate keys" : "Sortu gakoak",
    "Error generating key pair" : "Errorea gako bikotea sortzean",
    "All users. Type to select user or group." : "Erabiltzaile guztiak. Idatzi erabiltzaile edo taldea hautatzeko.",
    "(group)" : "(taldea)",
    "Enable encryption" : "Gaitu zifratzea",
    "Enable previews" : "Gaitu aurrebistak",
    "Enable sharing" : "Gaitu partekatzea",
    "Check for changes" : "Begiratu aldaketarik dagoen",
    "Never" : "inoiz ez",
    "Delete" : "Ezabatu",
    "Admin defined" : "Administratzaileak definitua",
    "Delete storage?" : "Ezabatu biltegiratzea?",
    "Saved" : "Gordeta",
    "Saving..." : "Gordetzen...",
    "Save" : "Gorde",
    "Username" : "Erabiltzaile izena",
    "Password" : "Pasahitza",
    "Credentials saved" : "Kredentzialak gordeta",
    "Credentials saving failed" : "Kredentzialak gordetzeak huts egin du",
    "Credentials required" : "Kredentzialak behar dira",
    "Invalid mount point" : "Muntatze-puntu baliogabea",
    "%s" : "%s",
    "Access key" : "Sarbide-gakoa",
    "Secret key" : "Gako sekretua",
    "Builtin" : "Integratua",
    "None" : "Ezer",
    "OAuth1" : "OAuth1",
    "App key" : "Aplikazio gakoa",
    "App secret" : "App sekretua",
    "OAuth2" : "OAuth2",
    "Client ID" : "Bezero ID",
    "Client secret" : "Bezeroaren Sekretua",
    "OpenStack v2" : "OpenStack v2",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domeinua",
    "API key" : "APIaren gakoa",
    "Global credentials" : "Kredentzial globalak",
    "Username and password" : "Erabiltzaile-izena eta pasahitza",
    "Log-in credentials, save in session" : "Saioa hasteko kredentzialak, gorde saioan",
    "RSA public key" : "RSA gako publikoa",
    "Public key" : "Gako publikoa",
    "RSA private key" : "RSA gako pribatua",
    "Private key" : "Gako pribatua",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "Ostalari izena",
    "Port" : "Portua",
    "Region" : "Eskualdea",
    "Enable SSL" : "Gaitu SSL",
    "Enable Path Style" : "Gaitu Bide Estiloa",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Urruneko azpikarpeta",
    "Secure https://" : "https:// segurua",
    "FTP" : "FTP",
    "Host" : "Ostalaria",
    "Secure ftps://" : "ftps:// segurua",
    "Local" : "Bertakoa",
    "Location" : "Kokapena",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Erroa",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Partekatu",
    "SMB / CIFS using OC login" : "SMB / CIFS saioa hasteko OC erabiliz",
    "Username as share" : "Erabiltzaile izena elkarbanaketa bezala",
    "OpenStack Object Storage" : "OpenStack Objektu Biltegiratzea",
    "Service name" : "Zerbitzuaren izena",
    "Name" : "Izena",
    "Storage type" : "Biltegiratze mota",
    "Scope" : "Esparrua",
    "Folder name" : "Karpetaren izena",
    "External storage" : "Kanpoko biltegiratzea",
    "Authentication" : "Autentifikazioa",
    "Configuration" : "Konfigurazioa",
    "Available for" : "Hauentzat eskuragarri",
    "Add storage" : "Gehitu biltegiratzea",
    "Advanced settings" : "Ezarpen aurreratuak"
},
"nplurals=2; plural=(n != 1);");
